import { Build, BuildDefinitionReference } from 'azure-devops-node-api/interfaces/BuildInterfaces';
import { Project, RepoBuild, GitTag, PullRequestOptions, PullRequest, DashboardPullRequest, Team, TeamMember, BuildRun } from '@backstage/plugin-azure-devops-common';
import { GitRepository } from 'azure-devops-node-api/interfaces/GitInterfaces';
import { UrlReader } from '@backstage/backend-common';
import { Config } from '@backstage/config';
import * as _backstage_backend_plugin_api from '@backstage/backend-plugin-api';
import { LoggerService } from '@backstage/backend-plugin-api';
import express from 'express';
import { PermissionEvaluator } from '@backstage/plugin-permission-common';
import { Entity } from '@backstage/catalog-model';
import { ScmIntegrationRegistry } from '@backstage/integration';
import { LocationSpec } from '@backstage/plugin-catalog-common';
import { CatalogProcessor } from '@backstage/plugin-catalog-node';

/** @public */
declare class AzureDevOpsApi {
    private readonly logger;
    private readonly urlReader;
    private readonly config;
    private readonly credentialsProvider;
    private constructor();
    static fromConfig(config: Config, options: {
        logger: LoggerService;
        urlReader: UrlReader;
    }): AzureDevOpsApi;
    private getWebApi;
    getProjects(host?: string, org?: string): Promise<Project[]>;
    getGitRepository(projectName: string, repoName: string, host?: string, org?: string): Promise<GitRepository>;
    getBuildList(projectName: string, repoId: string, top: number, host?: string, org?: string): Promise<Build[]>;
    getRepoBuilds(projectName: string, repoName: string, top: number, host?: string, org?: string): Promise<RepoBuild[]>;
    getGitTags(projectName: string, repoName: string, host?: string, org?: string): Promise<GitTag[]>;
    getPullRequests(projectName: string, repoName: string, options: PullRequestOptions, host?: string, org?: string): Promise<PullRequest[]>;
    getDashboardPullRequests(projectName: string, options: PullRequestOptions): Promise<DashboardPullRequest[]>;
    private getPullRequestPolicies;
    getAllTeams(options?: {
        limit?: number;
    }): Promise<Team[]>;
    getTeamMembers(options: {
        projectId: string;
        teamId: string;
    }): Promise<TeamMember[] | undefined>;
    getBuildDefinitions(projectName: string, definitionName: string, host?: string, org?: string): Promise<BuildDefinitionReference[]>;
    getBuilds(projectName: string, top: number, repoId?: string, definitions?: number[], host?: string, org?: string): Promise<Build[]>;
    getBuildRuns(projectName: string, top: number, repoName?: string, definitionName?: string, host?: string, org?: string): Promise<BuildRun[]>;
    getReadme(host: string, org: string, project: string, repo: string, path: string): Promise<{
        url: string;
        content: string;
    }>;
}

/** @public */
interface RouterOptions {
    azureDevOpsApi?: AzureDevOpsApi;
    logger: LoggerService;
    config: Config;
    reader: UrlReader;
    permissions: PermissionEvaluator;
}
/** @public */
declare function createRouter(options: RouterOptions): Promise<express.Router>;

/**
 * Azure DevOps backend plugin
 *
 * @public
 */
declare const azureDevOpsPlugin: () => _backstage_backend_plugin_api.BackendFeature;

/** @public */
declare class AzureDevOpsAnnotatorProcessor implements CatalogProcessor {
    private readonly opts;
    constructor(opts: {
        scmIntegrationRegistry: ScmIntegrationRegistry;
        kinds?: string[];
    });
    getProcessorName(): string;
    static fromConfig(config: Config, options?: {
        kinds?: string[];
    }): AzureDevOpsAnnotatorProcessor;
    preProcessEntity(entity: Entity, location: LocationSpec): Promise<Entity>;
}

export { AzureDevOpsAnnotatorProcessor, AzureDevOpsApi, type RouterOptions, createRouter, azureDevOpsPlugin as default };
